@@ -1,11 +1,11 @@
 package Data::CompactReadonly::V0::Node;
-our $VERSION = '0.0.6';
+our $VERSION = '0.1.0';
 
 use warnings;
 use strict;
 
 use Fcntl qw(:seek);
-use Scalar::Type qw(is_*);
+use Scalar::Type qw(is_* bool_supported);
 
 use Devel::StackTrace;
 use Data::CompactReadonly::V0::Text;
@@ -38,7 +38,11 @@ sub _stash_already_seen {
     my($class, %args) = @_;
     local $Data::Dumper::Indent   = 0;
     local $Data::Dumper::Sortkeys = 1;
-    if(defined($args{data})) {
+    if(bool_supported && is_bool($args{data})) {
+        $args{globals}->{already_seen}->{
+            $args{data} ? 'bt' : 'bf'
+        } = tell($args{fh});
+    } elsif(defined($args{data})) {
         $args{globals}->{already_seen}->{d}->{
             ref($args{data}) ? Dumper($args{data}) : $args{data}
         } = tell($args{fh});
@@ -52,11 +56,19 @@ sub _get_already_seen {
     my($class, %args) = @_;
     local $Data::Dumper::Indent   = 0;
     local $Data::Dumper::Sortkeys = 1;
-    return defined($args{data})
-        ? $args{globals}->{already_seen}->{d}->{
-              ref($args{data}) ? Dumper($args{data}) : $args{data}
-          }
-        : $args{globals}->{already_seen}->{u};
+
+    if(bool_supported && is_bool($args{data})) {
+        return
+            $args{data} ? $args{globals}->{already_seen}->{bt}
+                        : $args{globals}->{already_seen}->{bf}
+    } elsif(defined($args{data})) {
+        return
+            $args{globals}->{already_seen}->{d}->{
+                ref($args{data}) ? Dumper($args{data}) : $args{data}
+            }
+    } else {
+        return $args{globals}->{already_seen}->{u};
+    }
 }
 
 sub _get_next_free_ptr {
@@ -132,13 +144,13 @@ sub _text_type_for_data {
     };
 }
 
-# work out what node type is required to represent a piece of data. At least in
-# the case of numbers it might be better to look at the SV, as this won't distinguish
-# between 2 (the number) and "2" (the string).
+# work out what node type is required to represent a piece of data
 sub _type_map_from_data {
     my($class, $data) = @_;
     return !defined($data)
              ? 'Scalar::Null' :
+           (bool_supported && is_bool($data))
+             ? 'Scalar::'.($data ? 'True' : 'False') :
            ref($data) eq 'ARRAY'
              ? 'Array::'.do { $class->_sub_type_for_collection_of_length(1 + $#{$data}) ||
                               die("$class: Invalid: Array too long");
@@ -156,10 +168,10 @@ sub _type_map_from_data {
                  $bytes == 3 ? "Scalar::${neg}Medium" :
                  $bytes == 4 ? "Scalar::${neg}Long"   :
                  $bytes <  9 ? "Scalar::${neg}Huge"
-                             : "Scalar::Float"
+                             : "Scalar::Float64"
                } :
            is_number($data)
-             ? 'Scalar::Float' :
+             ? 'Scalar::Float64' :
            !ref($data)
              ? $class->_text_type_for_data($data)
              : die("Can't yet create from '$data'\n");
@@ -178,8 +190,10 @@ my $subtype_by_bits = {
     0b0110 => 'Long',      0b0111 => 'NegativeLong',
     0b1000 => 'Huge',      0b1001 => 'NegativeHuge',
     0b1010 => 'Null',
-    0b1011 => 'Float',
-    (map { $_ => 'Reserved' } (0b1100 .. 0b1111))
+    0b1011 => 'Float64',
+    0b1100 => 'True',
+    0b1101 => 'False',
+    (map { $_ => 'Reserved' } (0b1110 .. 0b1111))
 };
 my $bits_by_type    = { reverse %{$type_by_bits} };
 my $bits_by_subtype = { reverse %{$subtype_by_bits} };
@@ -207,7 +221,7 @@ sub _type_map_from_byte {
     die(sprintf("$class: Invalid type: 0b%08b: Reserved\n", $in_type))
         if($scalar_type eq 'Reserved');
     die(sprintf("$class: Invalid type: 0b%08b: length $scalar_type\n", $in_type))
-        if($type ne 'Scalar' && $scalar_type =~ /^(Null|Float|Negative|Huge)/);
+        if($type ne 'Scalar' && $scalar_type =~ /^(Null|Float64|Negative|Huge|True|False)/);
     return join('::', $type, $scalar_type);
 }
 
